pub struct ProgressPassConfig {
pub tiers: Vec<ProgressPassTierTemplate>,
pub premium_offer_template_id: OfferTemplateId,
}Fields
tiers: Vec<ProgressPassTierTemplate>Trait Implementations
Sourceimpl Clone for ProgressPassConfig
impl Clone for ProgressPassConfig
Sourcefn clone(&self) -> ProgressPassConfig
fn clone(&self) -> ProgressPassConfig
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressPassConfig
impl Debug for ProgressPassConfig
Sourceimpl Default for ProgressPassConfig
impl Default for ProgressPassConfig
Sourcefn default() -> ProgressPassConfig
fn default() -> ProgressPassConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProgressPassConfig
impl<'de> Deserialize<'de> for ProgressPassConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProgressPassConfig
impl JsonSchema for ProgressPassConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressPassConfig
impl PartialEq for ProgressPassConfig
Sourceimpl Serialize for ProgressPassConfig
impl Serialize for ProgressPassConfig
Sourceimpl Tsify for ProgressPassConfig
impl Tsify for ProgressPassConfig
const DECL: &'static str = "export interface ProgressPassConfig {\n tiers: ProgressPassTierTemplate[];\n premium_offer_template_id: OfferTemplateId;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ProgressPassConfig
impl StructuralPartialEq for ProgressPassConfig