pub struct ProgressPassState {
pub has_premium: bool,
pub tiers: Vec<ProgressPassTierState>,
}Fields
tiers: Vec<ProgressPassTierState>Trait Implementations
Sourceimpl Clone for ProgressPassState
impl Clone for ProgressPassState
Sourcefn clone(&self) -> ProgressPassState
fn clone(&self) -> ProgressPassState
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressPassState
impl Debug for ProgressPassState
Sourceimpl Default for ProgressPassState
impl Default for ProgressPassState
Sourcefn default() -> ProgressPassState
fn default() -> ProgressPassState
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProgressPassState
impl<'de> Deserialize<'de> for ProgressPassState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProgressPassState
impl JsonSchema for ProgressPassState
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressPassState
impl PartialEq for ProgressPassState
Sourceimpl Serialize for ProgressPassState
impl Serialize for ProgressPassState
Sourceimpl Tsify for ProgressPassState
impl Tsify for ProgressPassState
const DECL: &'static str = "export interface ProgressPassState {\n has_premium: boolean;\n tiers: ProgressPassTierState[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ProgressPassState
impl StructuralPartialEq for ProgressPassState