pub struct ProgressPassTierState {
pub tier: u32,
pub is_unlocked: bool,
pub free_claimed: bool,
pub paid_claimed: bool,
}Fields
tier: u32is_unlocked: boolfree_claimed: boolpaid_claimed: boolTrait Implementations
Sourceimpl Clone for ProgressPassTierState
impl Clone for ProgressPassTierState
Sourcefn clone(&self) -> ProgressPassTierState
fn clone(&self) -> ProgressPassTierState
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressPassTierState
impl Debug for ProgressPassTierState
Sourceimpl Default for ProgressPassTierState
impl Default for ProgressPassTierState
Sourcefn default() -> ProgressPassTierState
fn default() -> ProgressPassTierState
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProgressPassTierState
impl<'de> Deserialize<'de> for ProgressPassTierState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProgressPassTierState
impl JsonSchema for ProgressPassTierState
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressPassTierState
impl PartialEq for ProgressPassTierState
Sourceimpl Serialize for ProgressPassTierState
impl Serialize for ProgressPassTierState
Sourceimpl Tsify for ProgressPassTierState
impl Tsify for ProgressPassTierState
const DECL: &'static str = "export interface ProgressPassTierState {\n tier: number;\n is_unlocked: boolean;\n free_claimed: boolean;\n paid_claimed: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ProgressPassTierState
impl StructuralPartialEq for ProgressPassTierState