pub struct ProgressPassTierTemplate {
pub tier: u32,
pub quest_template_ids: Vec<QuestId>,
pub free_reward_bundle_id: BundleId,
pub paid_reward_bundle_id: BundleId,
}Fields
tier: u32quest_template_ids: Vec<QuestId>free_reward_bundle_id: BundleIdpaid_reward_bundle_id: BundleIdTrait Implementations
Sourceimpl Clone for ProgressPassTierTemplate
impl Clone for ProgressPassTierTemplate
Sourcefn clone(&self) -> ProgressPassTierTemplate
fn clone(&self) -> ProgressPassTierTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressPassTierTemplate
impl Debug for ProgressPassTierTemplate
Sourceimpl<'de> Deserialize<'de> for ProgressPassTierTemplate
impl<'de> Deserialize<'de> for ProgressPassTierTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProgressPassTierTemplate
impl JsonSchema for ProgressPassTierTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressPassTierTemplate
impl PartialEq for ProgressPassTierTemplate
Sourceimpl Serialize for ProgressPassTierTemplate
impl Serialize for ProgressPassTierTemplate
Sourceimpl Tsify for ProgressPassTierTemplate
impl Tsify for ProgressPassTierTemplate
const DECL: &'static str = "export interface ProgressPassTierTemplate {\n tier: number;\n quest_template_ids: QuestId[];\n free_reward_bundle_id: BundleId;\n paid_reward_bundle_id: BundleId;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ProgressPassTierTemplate
impl StructuralPartialEq for ProgressPassTierTemplate